#import "App_NameApplicationMode.h"
#import "App_NameAppDelegate.h"

@implementation App_NameApplicationMode
@synthesize backButton, square, movingBackground;

- (void)viewWillAppear:(BOOL)animated
	{
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
	
	//Set LaunchWithMenu Default So If User Quits Now The App Will Start Back Here
	[defaults setBool:NO forKey:LaunchWithMenu];
	
	//Display Proper Square Color And It's Saved Origin
	if ([defaults integerForKey:ApplicationModeKey] == 1)	
		{
		//Red Square
		CGRect squareFrame = CGRectMake([defaults floatForKey:RedSquareOriginX], [defaults floatForKey:RedSquareOriginY], 50, 50);
		UIView *aRedSquareView = [[UIView alloc] initWithFrame:squareFrame];
		aRedSquareView.backgroundColor = [UIColor redColor];
		self.square = aRedSquareView;
		[aRedSquareView release];
		}

	if ([defaults integerForKey:ApplicationModeKey] == 2)	
		{
		//Blue Square
		CGRect squareFrame = CGRectMake([defaults floatForKey:BlueSquareOriginX], [defaults floatForKey:BlueSquareOriginY], 50, 50);
		UIView *aBlueSquareView = [[UIView alloc] initWithFrame:squareFrame];
		aBlueSquareView.backgroundColor = [UIColor blueColor];
		self.square = aBlueSquareView;
		}
	
	//Create Moving Background
	CGRect aMovingRect = CGRectMake (0,	-63, 500 + 78, 500 + 63);
	UIView *aMovingView = [[UIView alloc] initWithFrame:aMovingRect];
	aMovingView.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"movingBackground.png"]];
	self.movingBackground = aMovingView;
	[aMovingView release];
	
	//Add Programatically Created Subviews To Hierarchy
	[self.view insertSubview:movingBackground atIndex:0];
	[self.view insertSubview:square atIndex:1];
	[self.square setUserInteractionEnabled:YES];
	
	//Always Start With Moving Background Moving
	[self startMovingBackground];
	
	[super viewWillAppear:animated];
	}
	
- (void)viewWillDisappear:(BOOL)animated
	{
	[self.movingBackground removeFromSuperview];
	[self.square removeFromSuperview];
	[super viewWillDisappear:animated];
	}
	
- (IBAction)actionButtonsSwitch:(id)sender
	{
	switch ([sender tag])
		{
		case (1):	{
				//Set Application Mode Default So The App Will Start With Menu
				[[NSUserDefaults standardUserDefaults] setBool:YES forKey:LaunchWithMenu];
				
				//Dismiss Model View
				[self dismissModalViewControllerAnimated:NO];
				}
				break;
				
		case (2):	{
				NSLog(@"toggle moving background");
				//Reverse Bool Value
				movingBackgroundMoving = !movingBackgroundMoving;
				
				if (movingBackgroundMoving == NO)
					[self stopMovingBackground];
					else
					[self startMovingBackground];
				}
				break;
		}
	}
	
- (void)didReceiveMemoryWarning
	{
	[super didReceiveMemoryWarning];
	}

- (void)dealloc
	{
	[movingBackground release];
	[square release];
	[backButton release];
	[super dealloc];
	}
	
#pragma mark Touch Methods

- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
	{
	CGPoint point = [[touches anyObject] locationInView:square];
	firstTouchPoint = point;
	}
	
- (void)touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event
	{
	CGPoint point = [[touches anyObject] locationInView:square];
	CGRect frame = [square frame];
	
	frame.origin.x += point.x - firstTouchPoint.x;
	frame.origin.y += point.y - firstTouchPoint.y;
	[square setFrame:frame];
	}
	
- (void)touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event
	{
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
	
	//Save Red Square Location
	if ([defaults integerForKey:ApplicationModeKey] == 1)
		{
		CGRect frame = [square frame];
		[defaults setFloat:frame.origin.x forKey:RedSquareOriginX];
		[defaults setFloat:frame.origin.y forKey:RedSquareOriginY];
		}

	//Save Blue Square Location
	if ([defaults integerForKey:ApplicationModeKey] == 2)
		{
		CGRect frame = [square frame];
		[defaults setFloat:frame.origin.x forKey:BlueSquareOriginX];
		[defaults setFloat:frame.origin.y forKey:BlueSquareOriginY];
		}	
	}
	
#pragma mark Moving Background

- (void)stopMovingBackground
	{
	NSLog(@"stop");
	movingBackgroundMoving = NO;
	[UIView beginAnimations:@"stopMovingBackground" context:NULL];
	[UIView setAnimationCurve:UIViewAnimationCurveLinear];
	[UIView setAnimationBeginsFromCurrentState:YES];
	[UIView setAnimationDuration:0];
	[UIView setAnimationRepeatCount:1];
	CGAffineTransform transform = CGAffineTransformMakeTranslation(0, 0);
	movingBackground.transform = transform;
	[UIView commitAnimations];
	}
	
- (void)startMovingBackground
	{
	NSLog(@"start");
	movingBackgroundMoving = YES;
	[UIView beginAnimations:@"startMovingBackground" context:NULL];
	[UIView setAnimationCurve:UIViewAnimationCurveLinear];
	[UIView setAnimationBeginsFromCurrentState:YES];
	[UIView setAnimationDuration:0.5];
	[UIView setAnimationRepeatCount:FLT_MAX];
	CGAffineTransform transform = CGAffineTransformMakeTranslation(-78, 63);
	movingBackground.transform = transform;
	[UIView commitAnimations];
	}
	
@end
