#import "App_NameMenu.h"
#import "App_NameApplicationMode.h"
#import "App_NameAppDelegate.h"

@implementation App_NameMenu
@synthesize redSquareButton, blueSquareButton, App_NameApplicationModeClass;

- (void)viewWillAppear:(BOOL)animated
	{
	//Launch App With Either Menu Or Application Mode
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
	
	//Zero Second Duration Animations To Application Mode Gives Appearance Of Starting Where User Left Off
	//And Sets Up Proper Animation Starting Point Of This View When The Model View Is Dismissed
	if ([defaults boolForKey:LaunchWithMenu] == NO)	
		{
		[self setButtonTitles];
		[self animateToApplicationMode:nil];
		return;
		}
	
	//If ApplicatonModeKey Is 0, Start Application In Normal State.
	//Else, Return From Application Mode With Proper Animation
	if ([defaults integerForKey:ApplicationModeKey] == 0)
		{
		[self setButtonTitles];
		}
		else
		{
		//Return From Application Mode To Menu
		[self animateFromApplicationMode];
		}
		
	[super viewWillAppear:animated];	
	}

- (IBAction)animateToApplicationMode:(id)sender
	{
	//Animation Block
	[UIView beginAnimations:@"animateToApplicationMode" context:NULL];
	[UIView setAnimationDelegate:self];
	[UIView setAnimationDidStopSelector:@selector(animationDidStop:finished:context:)];
	[UIView setAnimationCurve:UIViewAnimationCurveEaseIn];
	
	//The Button's Tag Is Saved To NSUserDefaults' ApplicationModeKey
	//So The Correct Animation Will Start Here And Then The Correct Mode Will Display When Mode View (ApplicationMode) Appears
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
	
	if ([defaults boolForKey:LaunchWithMenu] == YES)
		{
		//Standard Animation Duration To Application Mode
		[UIView setAnimationDuration:0.5];
		switchInteger = [sender tag];
		}
		else
		{
		//Zero Animation Duration To Applicaton Mode And Automatically Assign Sender Tag
		[UIView setAnimationDuration:0.0];
		switchInteger = [defaults integerForKey:ApplicationModeKey];
		}
	
	switch (switchInteger)
		{
		case (1):	{
				//Set The Applicaton Mode Key (Incase Button With Sender Triggered This Method)
				[defaults setInteger:1 forKey:ApplicationModeKey];
				
				//Animate The Red Button
				CGAffineTransform transform = CGAffineTransformMakeTranslation(320, 0);
				self.redSquareButton.transform = transform;
				break;
				}
		case (2):	{
				//Set The Applicaton Mode Key (Incase Button With Sender Triggered This Method)
				[defaults setInteger:2 forKey:ApplicationModeKey];
				
				//Animate The Blue Button
				CGAffineTransform transform = CGAffineTransformMakeTranslation(320, 0);
				self.blueSquareButton.transform = transform;
				break;
				}
		}
	
	[UIView commitAnimations];
	}
	
- (void)animateFromApplicationMode
	{
	//Animation Block
	[UIView beginAnimations:@"animateFromApplicationMode" context:NULL];
	[UIView setAnimationCurve:UIViewAnimationCurveEaseOut];
	[UIView setAnimationBeginsFromCurrentState:YES];
	[UIView setAnimationDuration:0.5];
	
	//Move The Animated Button Back To Original Position
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
	switch ([defaults integerForKey:ApplicationModeKey])
		{
		case (1):	{
				//Reset The ApplicationModeKey Default To 0
				[defaults setInteger:0 forKey:ApplicationModeKey];

				//Animate The Red Button Back To Original Position
				CGAffineTransform transform = CGAffineTransformMakeTranslation(0, 0);
				self.redSquareButton.transform = transform;
				}
				break;

		case (2):	{
				//Reset The ApplicationModeKey Default To 0
				[defaults setInteger:0 forKey:ApplicationModeKey];

				//Animate The Blue Button Back To Original Position
				CGAffineTransform transform = CGAffineTransformMakeTranslation(0, 0);
				self.blueSquareButton.transform = transform;
				}
				break;
		}

	[UIView commitAnimations];	
	}

- (void)animationDidStop:(NSString *)animationID finished:(NSNumber *)finished context:(void *)context
	{
	if ((animationID == @"animateToApplicationMode") && finished)
		[self presentModalViewController:App_NameApplicationModeClass animated:NO];
	}

- (void)setButtonTitles
	{
	[self.redSquareButton setTitle:@"Red Square" forState:UIControlStateNormal];
	[self.blueSquareButton setTitle:@"Blue Square" forState:UIControlStateNormal];
	}	

- (void)didReceiveMemoryWarning
	{
	[super didReceiveMemoryWarning];
	}
	
- (void)dealloc
	{
	[redSquareButton release];
	[blueSquareButton release];
	[App_NameApplicationModeClass release];
	[super dealloc];
	}

@end
